echo "Collecting debug information in file \"error_log.zip\"..."

# Delete error_log.zip if it already exists
if test -f "error_log.zip"; then
	rm error_log.zip
fi

# Capture structure of ejump_rp_usb folder
ls -1 . > ejump_rp_usb.log
mkdir debug
mv ejump_rp_usb.log debug/ejump_rp_usb.log

# Capture installed packages
apt --installed list > debug/installed.log 2> /dev/null

# Capture installed libraries
ls -1 /usr/lib > debug/usr_lib.log
ls -1 /usr/local/lib > debug/usr_local_lib.log

# Capture known libraries
ldconfig -p > debug/ldconfig.log

# Collect information about libopencv-dev
mkdir debug/libopencv-dev
apt-cache policy libopencv-dev > debug/libopencv-dev/apt-cache.stdout.log 2> debug/libopencv-dev/apt-cache.stderr.log
dpkg-query -L libopencv-dev > debug/libopencv-dev/dpkg-query.stdout.log 2> debug/libopencv-dev/dpkg-query.stderr.log
pkg-config --libs libopencv-dev > debug/libopencv-dev/pkg-config-libs.stdout.log 2> debug/libopencv-dev/pkg-config-libs.stderr.log
pkg-config --cflags libopencv-dev > debug/libopencv-dev/pkg-config-cflags.stdout.log 2> debug/libopencv-dev/pkg-config-cflags.stderr.log

# Collect information about libusb-1.0-0-dev
mkdir debug/libusb-1.0-0-dev
apt-cache policy libusb-1.0-0-dev > debug/libusb-1.0-0-dev/apt-cache.stdout.log 2> debug/libusb-1.0-0-dev/apt-cache.stderr.log
dpkg-query -L libusb-1.0-0-dev > debug/libusb-1.0-0-dev/dpkg-query.stdout.log 2> debug/libusb-1.0-0-dev/dpkg-query.stderr.log
pkg-config --libs libusb > debug/libusb-1.0-0-dev/pkg-config-libs.stdout.log 2> debug/libusb-1.0-0-dev/pkg-config-libs.stderr.log
pkg-config --cflags libusb > debug/libusb-1.0-0-dev/pkg-config-cflags.stdout.log 2> debug/libusb-1.0-0-dev/pkg-config-cflags.stderr.log

# Collect information about python3
mkdir debug/python
apt-cache policy python3 > debug/python/apt-cache.stdout.log 2> debug/python/apt-cache.stderr.log
python3 -m pip list > debug/python/pip_list.stdout.log 2> debug/python/pip_list.stderr.log

# Collect information about the eJump library
mkdir debug/libtcon-dev_usb
nm usr/lib/libtcon-dev_usb.so > debug/libtcon-dev_usb/nm.stdout.log 2> debug/libtcon-dev_usb/nm.stderr.log
ldd usr/lib/libtcon-dev_usb.so > debug/libtcon-dev_usb/ldd.stdout.log 2> debug/libtcon-dev_usb/ldd.stderr.log

# Collect information about linux setup
mkdir debug/linux
uname -a > debug/linux/uname.log

# Collect information about build process
mkdir debug/ejump_usb
make clean > /dev/null 2> /dev/null
make > debug/ejump_usb/make.stdout.log 2> debug/ejump_usb.stderr.log

# Collect information about run process
IMAGE_FILE=$(find . -name '*' -exec file {} \; | grep -o -P '.+\.(?:bmp|dib|jpeg|jpg|jpe|jp2|png|webp|pbm|pgm|ppm|pxm|pnm|pfm|sr|ras|tiff|tif|exr|hdr|pic)' | head -n 1)
echo $IMAGE_FILE > debug/ejump_usb/image_file.stdout.log 2> debug/ejump_usb/image_file.stderr.log
sudo ./ejump_usb $IMAGE_FILE > debug/ejump_usb/run_cpp.stdout.log 2> debug/ejump_usb/run_cpp.stderr.log
sudo python3 ejump_usb.py $IMAGE_FILE > debug/ejump_usb/run_py.stdout.log 2> debug/ejump_usb/run_py.stderr.log

# Install zip package if not already installed
dpkg -s zip > /dev/null
if test $? = 1; then
	echo "Installing the package \"zip\"..."
	apt install zip
fi

# Zipping everything
zip -r error_log.zip -- debug > /dev/null
echo ""
echo "Finished. Please forward \"error_log.zip\" to your sales representative at Beck."

# Removing the temp folder
rm -r debug
